==> duckplyr_0.2.1.tar.gz: duckplyr/R/restore.R <==
#' @export
methods_restore <- function() {
  vctrs::s3_register("dplyr::add_count", "data.frame", dplyr$add_count.data.frame)
  vctrs::s3_register("dplyr::anti_join", "data.frame", dplyr$anti_join.data.frame)
  vctrs::s3_register("dplyr::arrange", "data.frame", dplyr$arrange.data.frame)
  vctrs::s3_register("dplyr::auto_copy", "data.frame", dplyr$auto_copy.data.frame)
  vctrs::s3_register("dplyr::collect", "data.frame", dplyr$collect.data.frame)
  vctrs::s3_register("dplyr::compute", "data.frame", dplyr$compute.data.frame)
  vctrs::s3_register("dplyr::count", "data.frame", dplyr$count.data.frame)
  vctrs::s3_register("dplyr::cross_join", "data.frame", dplyr$cross_join.data.frame)
  vctrs::s3_register("dplyr::distinct", "data.frame", dplyr$distinct.data.frame)
  vctrs::s3_register("dplyr::do", "data.frame", dplyr$do.data.frame)
  vctrs::s3_register("dplyr::dplyr_reconstruct", "data.frame", dplyr$dplyr_reconstruct.data.frame)
  vctrs::s3_register("dplyr::filter", "data.frame", dplyr$filter.data.frame)
  vctrs::s3_register("dplyr::full_join", "data.frame", dplyr$full_join.data.frame)
  vctrs::s3_register("dplyr::group_vars", "data.frame", dplyr$group_vars.data.frame)
  vctrs::s3_register("dplyr::inner_join", "data.frame", dplyr$inner_join.data.frame)
  vctrs::s3_register("dplyr::intersect", "data.frame", dplyr$intersect.data.frame)
  vctrs::s3_register("dplyr::left_join", "data.frame", dplyr$left_join.data.frame)
  vctrs::s3_register("dplyr::mutate", "data.frame", dplyr$mutate.data.frame)
  vctrs::s3_register("dplyr::nest_by", "data.frame", dplyr$nest_by.data.frame)
  vctrs::s3_register("dplyr::nest_join", "data.frame", dplyr$nest_join.data.frame)
  vctrs::s3_register("dplyr::pull", "data.frame", dplyr$pull.data.frame)
  vctrs::s3_register("dplyr::reframe", "data.frame", dplyr$reframe.data.frame)
  vctrs::s3_register("dplyr::relocate", "data.frame", dplyr$relocate.data.frame)
  vctrs::s3_register("dplyr::rename", "data.frame", dplyr$rename.data.frame)
  vctrs::s3_register("dplyr::rename_with", "data.frame", dplyr$rename_with.data.frame)
  vctrs::s3_register("dplyr::right_join", "data.frame", dplyr$right_join.data.frame)
  vctrs::s3_register("dplyr::rows_append", "data.frame", dplyr$rows_append.data.frame)
  vctrs::s3_register("dplyr::rows_delete", "data.frame", dplyr$rows_delete.data.frame)
  vctrs::s3_register("dplyr::rows_insert", "data.frame", dplyr$rows_insert.data.frame)
  vctrs::s3_register("dplyr::rows_patch", "data.frame", dplyr$rows_patch.data.frame)
  vctrs::s3_register("dplyr::rows_update", "data.frame", dplyr$rows_update.data.frame)
  vctrs::s3_register("dplyr::rows_upsert", "data.frame", dplyr$rows_upsert.data.frame)
  vctrs::s3_register("dplyr::sample_frac", "data.frame", dplyr$sample_frac.data.frame)
  vctrs::s3_register("dplyr::sample_n", "data.frame", dplyr$sample_n.data.frame)
  vctrs::s3_register("dplyr::select", "data.frame", dplyr$select.data.frame)
  vctrs::s3_register("dplyr::semi_join", "data.frame", dplyr$semi_join.data.frame)
  vctrs::s3_register("dplyr::setdiff", "data.frame", dplyr$setdiff.data.frame)
  vctrs::s3_register("dplyr::setequal", "data.frame", dplyr$setequal.data.frame)
  vctrs::s3_register("dplyr::slice", "data.frame", dplyr$slice.data.frame)
  vctrs::s3_register("dplyr::slice_head", "data.frame", dplyr$slice_head.data.frame)
  vctrs::s3_register("dplyr::slice_tail", "data.frame", dplyr$slice_tail.data.frame)
  vctrs::s3_register("dplyr::summarise", "data.frame", dplyr$summarise.data.frame)
  vctrs::s3_register("dplyr::symdiff", "data.frame", dplyr$symdiff.data.frame)
  vctrs::s3_register("dplyr::transmute", "data.frame", dplyr$transmute.data.frame)
  vctrs::s3_register("dplyr::ungroup", "data.frame", dplyr$ungroup.data.frame)
  vctrs::s3_register("dplyr::union", "data.frame", dplyr$union.data.frame)
  vctrs::s3_register("dplyr::union_all", "data.frame", dplyr$union_all.data.frame)
}

==> duckplyr_0.3.0.tar.gz: duckplyr/R/restore.R <==
#' @export
methods_restore <- function() {
  vctrs::s3_register("dplyr::add_count", "data.frame", dplyr$add_count.data.frame)
  vctrs::s3_register("dplyr::anti_join", "data.frame", dplyr$anti_join.data.frame)
  vctrs::s3_register("dplyr::arrange", "data.frame", dplyr$arrange.data.frame)
  vctrs::s3_register("dplyr::auto_copy", "data.frame", dplyr$auto_copy.data.frame)
  vctrs::s3_register("dplyr::collect", "data.frame", dplyr$collect.data.frame)
  vctrs::s3_register("dplyr::compute", "data.frame", dplyr$compute.data.frame)
  vctrs::s3_register("dplyr::count", "data.frame", dplyr$count.data.frame)
  vctrs::s3_register("dplyr::cross_join", "data.frame", dplyr$cross_join.data.frame)
  vctrs::s3_register("dplyr::distinct", "data.frame", dplyr$distinct.data.frame)
  vctrs::s3_register("dplyr::do", "data.frame", dplyr$do.data.frame)
  vctrs::s3_register("dplyr::filter", "data.frame", dplyr$filter.data.frame)
  vctrs::s3_register("dplyr::full_join", "data.frame", dplyr$full_join.data.frame)
  vctrs::s3_register("dplyr::group_vars", "data.frame", dplyr$group_vars.data.frame)
  vctrs::s3_register("dplyr::inner_join", "data.frame", dplyr$inner_join.data.frame)
  vctrs::s3_register("dplyr::intersect", "data.frame", dplyr$intersect.data.frame)
  vctrs::s3_register("dplyr::left_join", "data.frame", dplyr$left_join.data.frame)
  vctrs::s3_register("dplyr::mutate", "data.frame", dplyr$mutate.data.frame)
  vctrs::s3_register("dplyr::nest_by", "data.frame", dplyr$nest_by.data.frame)
  vctrs::s3_register("dplyr::nest_join", "data.frame", dplyr$nest_join.data.frame)
  vctrs::s3_register("dplyr::pull", "data.frame", dplyr$pull.data.frame)
  vctrs::s3_register("dplyr::reframe", "data.frame", dplyr$reframe.data.frame)
  vctrs::s3_register("dplyr::relocate", "data.frame", dplyr$relocate.data.frame)
  vctrs::s3_register("dplyr::rename", "data.frame", dplyr$rename.data.frame)
  vctrs::s3_register("dplyr::rename_with", "data.frame", dplyr$rename_with.data.frame)
  vctrs::s3_register("dplyr::right_join", "data.frame", dplyr$right_join.data.frame)
  vctrs::s3_register("dplyr::rows_append", "data.frame", dplyr$rows_append.data.frame)
  vctrs::s3_register("dplyr::rows_delete", "data.frame", dplyr$rows_delete.data.frame)
  vctrs::s3_register("dplyr::rows_insert", "data.frame", dplyr$rows_insert.data.frame)
  vctrs::s3_register("dplyr::rows_patch", "data.frame", dplyr$rows_patch.data.frame)
  vctrs::s3_register("dplyr::rows_update", "data.frame", dplyr$rows_update.data.frame)
  vctrs::s3_register("dplyr::rows_upsert", "data.frame", dplyr$rows_upsert.data.frame)
  vctrs::s3_register("dplyr::select", "data.frame", dplyr$select.data.frame)
  vctrs::s3_register("dplyr::semi_join", "data.frame", dplyr$semi_join.data.frame)
  vctrs::s3_register("dplyr::setdiff", "data.frame", dplyr$setdiff.data.frame)
  vctrs::s3_register("dplyr::setequal", "data.frame", dplyr$setequal.data.frame)
  vctrs::s3_register("dplyr::slice", "data.frame", dplyr$slice.data.frame)
  vctrs::s3_register("dplyr::slice_head", "data.frame", dplyr$slice_head.data.frame)
  vctrs::s3_register("dplyr::slice_sample", "data.frame", dplyr$slice_sample.data.frame)
  vctrs::s3_register("dplyr::slice_tail", "data.frame", dplyr$slice_tail.data.frame)
  vctrs::s3_register("dplyr::summarise", "data.frame", dplyr$summarise.data.frame)
  vctrs::s3_register("dplyr::symdiff", "data.frame", dplyr$symdiff.data.frame)
  vctrs::s3_register("dplyr::transmute", "data.frame", dplyr$transmute.data.frame)
  vctrs::s3_register("dplyr::ungroup", "data.frame", dplyr$ungroup.data.frame)
  vctrs::s3_register("dplyr::union", "data.frame", dplyr$union.data.frame)
  vctrs::s3_register("dplyr::union_all", "data.frame", dplyr$union_all.data.frame)
}
